// Code generated by cmd/cgo -godefs; DO NOT EDIT.
// cgo -godefs sysconf_values_netbsd.go

//go:build netbsd && arm64
// +build netbsd,arm64

package sysconf

const (
	_LONG_MAX = 0x7fffffffffffffff
)
