// Code generated by cmd/cgo -godefs; DO NOT EDIT.
// cgo -godefs sysconf_values_freebsd.go

//go:build freebsd && 386
// +build freebsd,386

package sysconf

const (
	_LONG_MAX = 0x7fffffff
	_SHRT_MAX = 0x7fff
)
